from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x08\x00\x55\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x9b\x08\x00\x00\x00\x00\x00\x18\x6e\x00\xdc\x6e\x47\x6e\xdd\x75\xb4\x38\x2b\xee\x77\xe3\x8e\x03\x00\x00\x00\x00\x00\x00\x00\x00\xe7\x5b\x2b\x20\x11\x87\xe7\xd2\xee\xfd\xa1\xbb\xf3\x00\xb2\xee\xac\x34\x19\x73\x0d\x45\xff\xe5\x83\x9a\x60\xe4\x8a\x5f\x98\x30\x10\xd1\xd9\x64\xa2\xbc\xc1\xa5\x09\xa1\x2d\xd2\x72\x8b\x25\xe7\xbb\x70\x70\x16\x57\x76\x34\x4d\x4c\xbc\xe2\xc2\xe8\x16\x07\xd8\x06\xbb\x99\xef\x9e\x98\x35\x25\x80\x9b\xdc\x5a\x06\x91\x39\x20\xcd\xd7\xa3\xc1\x67\x52\x9e\xc4\x10\x77\x4e\x35\xae\x22\x2f\x56\xa9\xa1\x33\xc1\x33\x89\x9d\xcf\x73\xe3\xbd\x41\x0d\x76\x0a\xd8\x07\x1b\x78\x7d\xdf\x08\x3e\xa0\x7a\x7b\x55\x3b\x0b\x99\xe9\x48\x77\x07\xd2\x09\x34\xd7\x13\x1f\x6c\x05\x5a\x2c\x12\x3d\x6e\x74\xb3\x02\x01\x52\xa9\x94\x90\x61\x87\xe0\x22\xf8\xd5\x5f\x7e\xe9\xc2\xbd\xd4\xa6\xba\xea\xe9\x4c\x5b\xd9\xcc\x7f\x89\x0a\xf3\x99\x5a\x07\x88\xcf\x30\xba\xa5\x34\x1f\xae\x4a\xc3\x2c\x60\xb3\x2f\x1f\x62\x67\xdb\x00\x99\x4a\x27\xa3\x6a\x00\xc7\x66\xda\x34\xa5\x15\xf8\xb3\xae\xa0\x30\xc5\x06\xfc\xf3\x3d\x30\xd2\x91\x5f\xb4\x45\xf8\xee\x5a\x6b\x9e\x31\xc2\xe2\x34\x00\xc9\xad\x0f\x87\x5c\xe3\x66\x42\xf1\xee\xe6\x54\xa6\x69\xf7\xcb\x78\xb8\xe4\x61\xd1\x7c\xfc\xf5\x8f\xc2\xfe\xaa\x53\xa0\x7e\x4c\x60\x53\x2d\x23\x7a\xfd\x3b\xa6\xbf\xf6\xfa\x9d\xb4\x00\xc1\x72\x7e\xa2\x46\xc6\x1b\x4c\x23\x9e\xbe\x28\x89\x90\xd0\xe2\xbb\xd9\xff\x1c\xcf\x7e\xac\x37\x61\x6e\x28\x80\xa8\xaa\x5f\x99\xbd\x3d\xe1\xf0\xe4\xbd\xb3\xa6\x5b\x25\xd2\x3b\xbc\xed\x49\x34\x69\xdc\x42\x65\xb1\xd0\x50\xd7\xd3\x8d\xa0\x35\x96\xb7\xe2\x2b\x87\x20\x99\x58\x4d\xea\x02\x7f\x17\x5c\x84\x11\xa6\xef\x61\x6e\x68\xf9\xd8\xeb\xa3\xce\x2d\xb4\x50\x3d\xe0\x18\x78\xd7\x88\xd1\x1e\x06\xe4\x49\xed\x30\x52\x03\xe0\x49\x42\x91\xc9\xf7\xe6\xb4\x3f\x6c\x7b\x23\xbf\x53\xbf\x63\xb9\x6c\x09\x4a\x1a\x40\x84\xd8\x83\xae\x62\xa6\x2d\xfe\xf2\xf9\xa0\x18\x84\x8c\xc6\xc0\x8f\x72\xfb\x72\x88\xaf\x4b\x0d\xad\xfc\x9b\x65\x48\xff\x8d\x7f\xed\x66\x0d\xbd\xa2\x8f\x10\xb3\x54\xb0\x34\xac\x6d\xbc\x3a\xb3\x92\x76\x48\x63\x45\x79\xaa\x96\xd8\xce\xc3\xff\x71\xaa\xe0\xa3\x19\xc5\x8e\x15\x45\x44\xf7\x84\x2e\x61\xee\x5f\xdc\x21\xb4\xea\x78\x01\xc0\xb9\xff\x34\xb2\x07\x60\x1d\x58\x5f\x49\x52\x65\x4c\x47\x62\xba\x89\xa3\x6b\xc8\x53\x3e\x9f\x66\x43\xf1\xcb\xde\xe5\x25\x1f\x2f\x07\x78\xf2\xae\xce\x59\x6b\xc0\xee\x30\x59\x0a\xdc\x26\x3b\x89\x9f\x95\x64\x3b\x24\x9e\x31\xed\x47\x07\xc3\x9d\x82\x9d\x51\x0e\xbb\x04\x65\xc6\xec\x8b\x2e\x93\x6c\x9b\x9b\x36\x25\x4b\xea\x86\xed\x46\xc2\xa6\xe4\x94\x67\x0d\x46\x54\xd3\x54\x8a\xf8\x8e\x32\x58\x63\x4a\x35\x1a\xae\x28\x2e\xe1\x7e\xfb\x0b\xef\xb8\x50\x6f\xe1\xa4\x62\x90\x93\x4d\x35\x41\xdc\xb0\x70\x80\x1b\x74\x4a\x7d\xbf\x40\x4f\xaf\x2d\x04\xb3\x17\xfe\x9f\x52\x26\x70\x5d\xb0\x2e\x5e\x3f\xe1\x1b\xc1\xc3\x54\x17\xb7\xe8\x9c\x77\xe5\x68\x03\xb1\x4f\x17\x46\x9c\xaf\xec\xf5\x56\xe8\x71\x60\x4c\xa1\x70\x60\x05\x36\x31\x97\xd9\xd9\x0d\x45\xdd\xbb\x07\x36\x2e\x17\xa6\x4d\x28\x39\xcf\xa0\x55\x9d\xfe\x97\xa0\x5a\x71\x03\xdc\xe7\x56\xee\x9e\x95\x66\xbe\xaa\x24\x35\xd1\x9e\x90\x2f\x82\xee\x06\x9e\x8b\xd0\x54\x4d\x7a\xe5\x89\xa1\xd8\x62\x22\xcb\xac\x5e\x46\x4c\xcb\x44\x72\x91\x0d\x4d\x83\xad\x61\x5f\x68\x6b\xfd\x49\x0f\xd0\xff\xf3\x7c\x5b\x4f\xa6\xde\x8b\xb9\xd6\xd8\x81\xc2\x59\xe6\xe1\xbf\x1d\x63\xbe\x25\xea\x61\x23\xf7\x8b\xd1\x31\xf3\x41\xcf\x3c\x83\xae\x10\x93\xed\xa5\x7f\x96\x60\x73\x32\x65\x4b\xb1\xdf\xad\x32\x27\x95\xa1\xf6\x5c\x6e\xbd\x1b\xf4\x51\xe9\x22\x4b\x99\x63\x66\xf6\x70\x83\x1b\x8a\xe4\x7d\x87\x8a\x78\x0e\x8c\x95\x43\x95\x55\xc6\x82\x3c\x0c\x10\xd8\x6c\xe3\xa2\xf5\x13\x28\x86\xcf\x90\x13\x01\x0e\x4c\x1f\x05\x96\xd7\x8f\x08\x00\xe6\xae\xee\x5c\x11\x99\x8f\xa9\xac\x90\xb4\x1e\x09\xcb\xcf\xd1\x58\x79\x31\x64\x05\xbc\x21\xd8\xaa\x16\xd1\xcc\x5a\x5f\xe1\xc1\x7e\x37\x6a\xa3\xd0\xfe\x69\xfc\x1a\x3e\x86\x71\x3e\x29\x76\xe3\x18\xb6\x3a\x7a\x94\x3a\xee\xeb\x79\x4f\x95\xe6\x4d\xb7\xd8\x75\x3f\x97\x25\x60\x45\x31\xa6\x50\x48\x47\x48\xcb\xce\x90\x9e\x59\x8b\xca\xc9\xc8\x5c\x15\x83\x4a\xed\xc7\x3b\x76\xba\x72\x90\x8a\x7e\x84\x26\xf8\xc2\xe6\x1d\x9c\x64\x93\xa9\xc7\xe9\x8d\x9b\x8b\x80\x6d\xea\x0f\x4e\xf4\x0a\xf2\x5c\x47\x0a\x7c\x7f\xd4\x24\x9c\x84\xb0\xad\x3d\xe7\x62\x04\x8c\x11\x2a\x9a\x57\x1f\x95\x8a\xc6\xf9\xc4\x85\xd1\x2a\xc3\x4e\x34\xfd\x25\x08\x4d\xd8\xc8\x50\xd0\x32\x5b\x5d\xd4\x62\x7b\xdf\x6a\x7d\x7b\xa3\x08\xe3\xfc\x99\x81\xb2\x5d\xbe\xa3\x6f\x3c\x4b\x26\xd9\x3e\xca\x42\xf4\x12\x36\xda\x5d\xbd\x92\xa9\x3d\x3b\xde\x5b\xe6\xab\xbe\xea\x9e\x9f\x20\xf1\x85\xad\x3e\x7f\x8f\xfe\x9d\x69\xca\xdd\xff\x2e\xd4\xa8\xbc\x07\xe8\x8b\x73\x01\x5a\xc5\xc6\x1d\x0a\xc0\x1e\x4a\x2e\xdf\x06\x04\x91\xab\xca\x5a\x00\x42\xe9\xcb\xfb\x4a\x43\x2f\x17\x84\x58\x4b\x8e\x15\xf6\xb3\x2e\xdf\x32\xa3\x5c\x82\xd1\x74\x19\xcc\x1e\x8d\x20\x95\x95\x1f\xb2\x50\x66\xbb\xff\xf5\xf9\xee\x14\x9c\xd7\x19\x7c\xca\xb5\x98\x12\xb3\x33\x5d\x81\xf8\x43\xcd\x3e\x86\xf6\x3f\x9e\xb6\xf9\xf6\x3d\x1c\x05\xef\x13\xed\x19\x8a\xbe\xc0\x34\x42\x74\xb7\x4d\xab\x8b\x8c\xaa\xf2\xa1\x2e\x36\x10\xea\x19\x28\xcb\xa7\x76\x42\x85\x9d\x29\x74\xd3\x8e\x08\xd2\x3a\xb2\x15\xf2\x5c\x42\xec\x03\xfe\x3a\x06\x69\x7b\xf7\xc6\xf4\x67\xa8\xdc\x0f\x1f\x15\xfb\xf6\x36\x47\x8b\x4d\x93\xc7\x0c\xea\x77\x03\x27\xd7\x01\xd4\x04\x00\xb7\x08\xaf\x5a\x7f\x7f\x33\x5e\xad\x99\x24\x14\x51\x3b\x26\xb0\xfb\x8c\x43\xce\x69\xe4\x6d\x81\x6d\x84\x64\xda\x12\x55\xba\xa2\x9f\xe9\xa7\xb9\xec\xfa\x87\x3b\xdf\xac\x7d\xa6\x2c\x85\xe1\xd6\xab\x03\xb5\x96\xd2\x22\x0f\xe6\x7d\x98\xf2\x22\xd2\x25\x39\xe2\x3d\x06\x6a\x57\x42\xc8\x5e\xc6\xa1\x82\x2e\xb4\xea\xca\x39\xe4\x3c\x82\xe4\xaf\x0f\x17\x76\xf5\xac\x39\x0c\x40\x06\x56\x0a\xef\xab\x8d\x7e\x68\xfd\xbc\x10\x47\xd9\x52\xa1\x58\x4b\x79\x34\xb0\xf3\x6a\x3f\x0b\x05\x7f\xc1\xd6\xa9\x5b\x56\x32\x29\x06\xfc\xff\xfc\xeb\x58\xe4\xc7\x82\x4d\xd6\xab\x2f\x27\xad\xa8\xc6\xc3\xde\x01\x27\x07\x68\x4c\xf7\x14\x09\xe5\xc0\xcf\xd4\x13\x42\x72\x20\x2e\x27\x47\xf9\xf8\x8b\x72\x1b\xcc\x7e\x00\xf9\xaf\x00\xce\xd0\xd5\x30\x0d\xf5\xc9\xe2\xd6\xa1\x23\xbd\x84\x74\x39\x2f\x31\xeb\x61\xc0\x49\xd6\x59\x8e\x5b\x59\x56\xd9\x78\xa9\x3e\x07\x53\xdc\xff\xbf\x58\xa0\x53\x71\x19\xb1\x85\x07\x7c\xc0\x6c\x60\x51\xc0\x7a\x07\xa5\xfc\x21\xd1\xb6\xaa\x57\xf9\xd8\xff\xc9\x91\x34\xbe\xa0\x45\xdd\x49\x10\x43\x63\x29\xcc\x43\xde\x26\xef\xd5\x40\x28\x37\x98\xe2\xf4\x0c\x16\x6b\xd4\x99\x11\xe4\x43\x47\x68\xc8\xd1\x1a\x04\x20\x0d\x1b\xee\xcf\x79\x0a\x7e\x9d\x68\x65\xf8\x89\x95\x1b\xfc\x0a\x69\xc3\x6c\x43\xea\x23\x0d\xd0\x03\x45\xf3\x7b\xa1\x1d\x07\x97\xf1\x2d\x24\xb5\x19\xa7\x98\x11\xbe\xcf\x4b\xe7\x09\xf5\xb9\x20\x1a\x79\xbc\x45\x1f\x36\x9f\x2a\x4c\x49\x98\xb9\x58\xe4\xb9\x4f\xef\x5f\xb3\xc7\x02\xdf\x27\xdc\x38\x1f\x4f\x97\x8f\x86\xfc\x73\xdb\xa3\xb0\xb8\x09\xbf\xca\xff\x7f\xbc\x98\x4d\x44\x1e\x62\xea\xbb\xc4\xa9\x93\xdd\x3b\x1f\xd0\x34\xa6\x1b\x15\xd0\xf4\x7b\x73\x31\x25\x4a\xd0\xd7\xd6\x9a\x76\x51\x79\x8c\x2c\x2c\xdf\x26\x47\x78\xf2\x7b\x15\x54\x1f\xf1\x0e\xdb\xae\x27\x0e\x12\xaa\x3c\xa3\xd5\x5d\x2f\xaa\xe8\xe1\x8d\xde\x8d\xcc\x36\x1f\xc6\x88\x7a\x43\xf7\x8f\xd2\x4b\x13\x49\xeb\x45\x2e\x62\xfa\xaf\x1a\x40\x2f\xdc\x17\x70\x21\x42\x59\x3b\x72\x02\x8a\xaa\x2c\x8e\xe5\x97\x04\xeb\x17\x3e\xeb\xbb\x37\xb3\x30\xa6\xf7\xfe\xc6\xfe\xe7\x18\x50\xb9\x62\x7a\x4b\x0a\x6a\xca\x6c\x16\x35\xe7\xb2\x62\xd8\x93\x3c\x57\x3b\x35\x9e\xea\xa2\x14\x0b\xcb\x07\x82\xcc\x35\xe1\x47\x3b\xa6\x0d\xbc\x11\x05\x66\xf3\x43\x44\x57\xbb\x3e\x7b\x68\x61\xf1\x81\x51\x7f\xee\x08\x34\xaf\x00\xfa\x0e\x8e\x6b\x15\xdf\x9e\x50\x0a\x1e\xf7\x25\x25\x88\xff\xbc\x0a\xda\xae\x69\xdc\x05\x92\xe9\x45\x3b\x70\x84\x2e\x4e\x90\xa0\xe3\x49\x6b\x54\x41\xd1\x81\xb0\xd5\xa8\x4b\xea\x19\x25\x21\xcf\x19\x06\xbd\xb9\xb0\x4a\xad\xf3\xd4\x35\x1b\x1d\xa1\x51\xdb\x6b\x07\xcf\x99\xf5\x48\x38\xad\xf3\x3b\x6c\x2f\x37\xd8\x78\x04\x23\xc2\x88\xe8\x3d\xbb\xf5\x4c\xd9\xc7\x9a\x3c\xbe\xac\xe7\xa9\x4f\xb4\x38\x94\x43\x96\xcd\x9f\xdd\x3b\x7a\x04\xa7\x9d\x0a\xab\x2f\xc0\x6a\xc9\x55\x38\x62\x17\xb2\x99\x07\x63\x70\x7a\x1f\xad\xaa\x23\x00\x02\xe0\x31\x7d\xc1\xd1\x57\x4d\x74\xc5\x77\xfb\xff\x5b\x44\xa3\x8a\x51\x58\x19\x70\xfc\xad\x48\x89\x27\x44\xe5\xb1\x6e\x18\xc1\xc6\xe4\xc8\x33\x67\xb2\x58\xcf\x4f\x7d\x21\xb8\x45\xdb\x29\x76\x7d\x1f\xf9\x99\xe6\x8f\x59\x1f\x8e\xec\x26\xb0\xbf\xbd\xd6\xf2\x1d\x91\x09\x9b\x49\x17\xde\x0d\x2e\x23\xab\x81\xbe\x5f\x8b\x7d\x7d\x1a\x00\x46\xd7\x6c\x42\x7f\x78\xa0\xe4\xba\xf9\x41\x68\x83\x1f\xb5\xef\x6e\xb2\x99\xbe\x08\x3f\x95\x62\xef\x65\x2d\x39\xd5\x47\xac\x70\x6f\x6e\x5a\xd7\x5e\x21\x4b\x69\xef\xad\xd7\x08\x61\x05\xa0\xf2\x68\x41\x0d\x73\x00\x91\xe4\xa4\x98\xc3\x1c\x11\x44\x7f\x91\xb2\x0f\x07\xde\x41\x8b\x2c\x7a\x22\x9d\xae\x17\xab\x95\xac\xd0\xf4\xab\x7a\x71\xe8\x89\xbf\x5f\x51\x01\x77\x68\xc7\x62\x03\x3a\x06\xe5\xa2\x71\x72\x03\x96\x58\x85\xa2\xc4\xaa\x93\x0a\x06\x77\x51\x25\xcb\x84\xf3\x88\x12\x90\x23\x02\xc5\xdb\x20\x21\x2b\xb2\x77\x32\x83\xf1\x3c\xf7\x8d\x9b\xd2\x80\xe5\x95\x21\x5f\xfe\xc7\x56\xf8\x9f\x2e\x73\x8b\x79\x87\x3d\x22\x9f\x5e\x9f\x58\xc1\x53\xcd\xfb\x87\x6e\xb8\x36\xbe\xc1\xf0\x4e\x6c\x5b\x30\x1c\xd3\xbc\xa8\x26\xf2\x6f\x10\x29\xa8\xe5\x73\x02\xb7\xdd\xd5\xea\xe2\x0f\x87\x6f\xbe\x72\x94\x62\xa8\xee\x82\xfc\x27\xbf\xee\xd5\x28\x57\xc1\x12\xa0\x13\x8b\x34\xa1', 2)

# cleanup
del pyarmor_runtime

